@@ -1,5 +1,5 @@
 
-from .hub import TaskHub,HubManager
+from .hub import TaskHub, HubManager
 from .connector import connect
 from multiprocessing import Process
 import time
@@ -24,8 +24,8 @@ def serve(port: int, passwd: str, sync):
         该函数负责处理这些完成状态的数据，并返回一个bool值，
         以表示处理成功与否，若成功taskhub将移除改该Task]
     """
-    p = Process(target=start_hub_serve,args=(port,passwd,sync,))
+    p = Process(target=start_hub_serve, args=(port, passwd, sync,))
     p.start()
     time.sleep(3)
-    hub = connect("localhost", port, passwd)
+    hub = connect("0.0.0.0", port, passwd)
     hub.serve()
